==> edge-login-ui-rn-1.4.1.tgz: package/lib/components/themed/MainButton.js <==
import * as React from 'react';
import { ActivityIndicator, Text, TouchableOpacity } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import { usePendingPress } from '../../hooks/usePendingPress';
import { textNoShadow, themeNoShadow } from '../../types/Theme';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
const primaryTextColorArray = ['transparent', 'transparent'];
const primaryTextStart = { x: 0, y: 0 };
const primaryTextEnd = { x: 0, y: 1 };
/**
 * A stand-alone button to perform the primary action in a modal or scene.
 */
export function MainButton(props) {
    const { alignSelf = 'auto', children, disabled = false, label, marginRem, onPress, type = 'primary', paddingRem, spinner = false, testID } = props;
    // `onPress` promise logic:
    const [pending, handlePress] = usePendingPress(onPress);
    // Styles:
    const theme = useTheme();
    const styles = getStyles(theme);
    let touchableStyle, textStyle, spinnerColor, colors, start, end, buttonShadow;
    if (type === 'primary') {
        touchableStyle = styles.primaryButton;
        textStyle = styles.primaryText;
        spinnerColor = theme.primaryButtonText;
        colors = theme.primaryButton;
        start = theme.primaryButtonColorStart;
        end = theme.primaryButtonColorEnd;
        buttonShadow = styles.primaryButtonShadow;
    }
    else if (type === 'secondary') {
        touchableStyle = styles.secondaryButton;
        textStyle = styles.secondaryText;
        spinnerColor = theme.secondaryButtonText;
        colors = theme.secondaryButton;
        start = theme.secondaryButtonColorStart;
        end = theme.secondaryButtonColorEnd;
        buttonShadow = styles.secondaryButtonShadow;
    }
    else if (type === 'textOnly') {
        touchableStyle = styles.textOnlyButton;
        textStyle = styles.textOnlyText;
        spinnerColor = theme.primaryText;
        colors = primaryTextColorArray;
        start = primaryTextStart;
        end = primaryTextEnd;
        buttonShadow = styles.textOnlyButtonShadow;
    }
    else {
        touchableStyle = styles.escapeButton;
        textStyle = styles.escapeText;
        spinnerColor = theme.escapeButtonText;
        colors = theme.escapeButton;
        start = theme.escapeButtonColorStart;
        end = theme.escapeButtonColorEnd;
        buttonShadow = styles.escapeButtonShadow;
    }
    const dynamicStyles = Object.assign(Object.assign({ alignSelf, opacity: disabled || pending ? 0.7 : 1 }, sidesToMargin(mapSides(fixSides(marginRem, 0), theme.rem))), sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem)));
    return (React.createElement(TouchableOpacity, { disabled: disabled || pending, style: buttonShadow, testID: testID, onPress: handlePress },
        React.createElement(LinearGradient, { colors: colors, start: start, end: end, style: [touchableStyle, dynamicStyles, styles.linearGradient] },
            label == null || pending ? null : (React.createElement(Text, { adjustsFontSizeToFit: true, minimumFontScale: 0.75, numberOfLines: 1, style: textStyle }, label)),
            pending ? null : children,
            !spinner && !pending ? null : (React.createElement(ActivityIndicator, { color: spinnerColor, style: styles.spinner })))));
}
const getStyles = cacheStyles((theme) => {
    const commonButton = {
        alignItems: 'center',
        borderRadius: theme.rem(theme.buttonBorderRadiusRem),
        flexDirection: 'row',
        justifyContent: 'center',
        minHeight: theme.rem(3),
        minWidth: theme.rem(7)
    };
    const commonText = {
        marginHorizontal: theme.rem(0),
        paddingTop: theme.rem(0.5),
        paddingBottom: theme.rem(0.5),
        paddingLeft: theme.rem(0.75),
        paddingRight: theme.rem(0.75)
    };
    return {
        linearGradient: {
            // flex: 1,
            paddingLeft: 0,
            paddingRight: 0,
            borderRadius: theme.rem(theme.buttonBorderRadiusRem)
        },
        primaryButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.primaryButtonOutline, borderWidth: theme.primaryButtonOutlineWidth }),
        primaryButtonShadow: Object.assign({}, theme.primaryButtonShadow),
        primaryText: Object.assign(Object.assign(Object.assign({}, commonText), theme.primaryButtonTextShadow), { fontFamily: theme.primaryButtonFont, fontSize: theme.rem(theme.primaryButtonFontSizeRem), color: theme.primaryButtonText }),
        secondaryButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.secondaryButtonOutline, borderWidth: theme.secondaryButtonOutlineWidth }),
        secondaryButtonShadow: Object.assign({}, theme.secondaryButtonShadow),
        secondaryText: Object.assign(Object.assign(Object.assign({}, commonText), theme.secondaryButtonTextShadow), { fontFamily: theme.secondaryButtonFont, fontSize: theme.rem(theme.secondaryButtonFontSizeRem), color: theme.secondaryButtonText }),
        escapeButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.escapeButtonOutline, borderWidth: theme.escapeButtonOutlineWidth }),
        escapeButtonShadow: Object.assign({}, theme.escapeButtonShadow),
        escapeText: Object.assign(Object.assign(Object.assign({}, commonText), theme.escapeButtonTextShadow), { fontFamily: theme.escapeButtonFont, fontSize: theme.rem(theme.escapeButtonFontSizeRem), color: theme.escapeButtonText }),
        textOnlyButton: Object.assign(Object.assign({}, commonButton), { borderColor: 'transparent', borderWidth: 0 }),
        textOnlyButtonShadow: Object.assign({}, themeNoShadow),
        textOnlyText: Object.assign(Object.assign(Object.assign({}, commonText), textNoShadow), { fontFamily: theme.fontFaceDefault, fontSize: theme.rem(1), color: theme.primaryText }),
        // Common styles:
        spinner: {
            height: theme.rem(1.875),
            marginHorizontal: theme.rem(0.5)
        }
    };
});

==> edge-login-ui-rn-1.5.0.tgz: package/lib/components/themed/MainButton.js <==
import * as React from 'react';
import { ActivityIndicator, Text, TouchableOpacity } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import s from '../../common/locales/strings';
import { usePendingPress } from '../../hooks/usePendingPress';
import { textNoShadow, themeNoShadow } from '../../types/Theme';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
const primaryTextColorArray = ['transparent', 'transparent'];
const primaryTextStart = { x: 0, y: 0 };
const primaryTextEnd = { x: 0, y: 1 };
/**
 * A stand-alone button to perform the primary action in a modal or scene.
 */
export function MainButton(props) {
    const { alignSelf = 'auto', children, disabled = false, label, marginRem, onPress, type = 'primary', paddingRem, spinner = false, testID } = props;
    // `onPress` promise logic:
    const [pending, handlePress] = usePendingPress(onPress);
    // Styles:
    const theme = useTheme();
    const styles = getStyles(theme);
    let touchableStyle, textStyle, spinnerColor, colors, start, end, buttonShadow;
    if (type === 'primary') {
        touchableStyle = styles.primaryButton;
        textStyle = styles.primaryText;
        spinnerColor = theme.primaryButtonText;
        colors = theme.primaryButton;
        start = theme.primaryButtonColorStart;
        end = theme.primaryButtonColorEnd;
        buttonShadow = styles.primaryButtonShadow;
    }
    else if (type === 'secondary') {
        touchableStyle = styles.secondaryButton;
        textStyle = styles.secondaryText;
        spinnerColor = theme.secondaryButtonText;
        colors = theme.secondaryButton;
        start = theme.secondaryButtonColorStart;
        end = theme.secondaryButtonColorEnd;
        buttonShadow = styles.secondaryButtonShadow;
    }
    else if (type === 'textOnly') {
        touchableStyle = styles.textOnlyButton;
        textStyle = styles.textOnlyText;
        spinnerColor = theme.primaryText;
        colors = primaryTextColorArray;
        start = primaryTextStart;
        end = primaryTextEnd;
        buttonShadow = styles.textOnlyButtonShadow;
    }
    else {
        touchableStyle = styles.escapeButton;
        textStyle = styles.escapeText;
        spinnerColor = theme.escapeButtonText;
        colors = theme.escapeButton;
        start = theme.escapeButtonColorStart;
        end = theme.escapeButtonColorEnd;
        buttonShadow = styles.escapeButtonShadow;
    }
    const dynamicStyles = Object.assign(Object.assign({ alignSelf, opacity: disabled || pending ? 0.7 : 1 }, sidesToMargin(mapSides(fixSides(marginRem, 0), theme.rem))), sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem)));
    return (React.createElement(TouchableOpacity, { disabled: disabled || pending, style: buttonShadow, testID: testID, onPress: handlePress },
        React.createElement(LinearGradient, { colors: colors, start: start, end: end, style: [touchableStyle, dynamicStyles, styles.linearGradient] },
            label == null || pending ? null : (React.createElement(Text, { adjustsFontSizeToFit: true, minimumFontScale: 0.75, numberOfLines: 1, style: textStyle }, label)),
            pending ? null : children,
            !spinner && !pending ? null : (React.createElement(ActivityIndicator, { color: spinnerColor, style: styles.spinner, accessibilityHint: s.strings.spin_load_hint })))));
}
const getStyles = cacheStyles((theme) => {
    const commonButton = {
        alignItems: 'center',
        borderRadius: theme.rem(theme.buttonBorderRadiusRem),
        flexDirection: 'row',
        justifyContent: 'center',
        minHeight: theme.rem(3),
        minWidth: theme.rem(7)
    };
    const commonText = {
        marginHorizontal: theme.rem(0),
        paddingTop: theme.rem(0.5),
        paddingBottom: theme.rem(0.5),
        paddingLeft: theme.rem(0.75),
        paddingRight: theme.rem(0.75)
    };
    return {
        linearGradient: {
            // flex: 1,
            paddingLeft: 0,
            paddingRight: 0,
            borderRadius: theme.rem(theme.buttonBorderRadiusRem)
        },
        primaryButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.primaryButtonOutline, borderWidth: theme.primaryButtonOutlineWidth }),
        primaryButtonShadow: Object.assign({}, theme.primaryButtonShadow),
        primaryText: Object.assign(Object.assign(Object.assign({}, commonText), theme.primaryButtonTextShadow), { fontFamily: theme.primaryButtonFont, fontSize: theme.rem(theme.primaryButtonFontSizeRem), color: theme.primaryButtonText }),
        secondaryButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.secondaryButtonOutline, borderWidth: theme.secondaryButtonOutlineWidth }),
        secondaryButtonShadow: Object.assign({}, theme.secondaryButtonShadow),
        secondaryText: Object.assign(Object.assign(Object.assign({}, commonText), theme.secondaryButtonTextShadow), { fontFamily: theme.secondaryButtonFont, fontSize: theme.rem(theme.secondaryButtonFontSizeRem), color: theme.secondaryButtonText }),
        escapeButton: Object.assign(Object.assign({}, commonButton), { borderColor: theme.escapeButtonOutline, borderWidth: theme.escapeButtonOutlineWidth }),
        escapeButtonShadow: Object.assign({}, theme.escapeButtonShadow),
        escapeText: Object.assign(Object.assign(Object.assign({}, commonText), theme.escapeButtonTextShadow), { fontFamily: theme.escapeButtonFont, fontSize: theme.rem(theme.escapeButtonFontSizeRem), color: theme.escapeButtonText }),
        textOnlyButton: Object.assign(Object.assign({}, commonButton), { borderColor: 'transparent', borderWidth: 0 }),
        textOnlyButtonShadow: Object.assign({}, themeNoShadow),
        textOnlyText: Object.assign(Object.assign(Object.assign({}, commonText), textNoShadow), { fontFamily: theme.fontFaceDefault, fontSize: theme.rem(1), color: theme.primaryText }),
        // Common styles:
        spinner: {
            height: theme.rem(1.875),
            marginHorizontal: theme.rem(0.5)
        }
    };
});
